@@ -12,11 +12,11 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::CommitBuild;
 {
-  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.121770';
+  $Dist::Zilla::Plugin::Git::CommitBuild::VERSION = '1.121800';
 }
 # ABSTRACT: checkin build results on separate branch
 
-use Git::Wrapper;
+use Git::Wrapper 0.021;
 use IPC::Open3;
 use IPC::System::Simple; # required for Fatalised/autodying system
 use File::chdir;
@@ -119,24 +119,8 @@ sub _commit_build {
 
     ### @parents
 
-    my @commit;
-    {
-        # Git::Wrapper doesn't read from STDIN, which is 
-        # needed for commit-tree, so we have to everything
-        # ourselves
-        #
-        my ($fh, $filename) = File::Temp::tempfile();
-        $fh->autoflush(1);
-        print $fh _format_message( $message, $self );
-
-        my @args=('git', 'commit-tree', $tree, map { ( -p => $_ ) } @parents);
-        push @args,'<'.$filename;
-        my $cmdline=join(' ',@args);
-        @commit=qx/$cmdline/;
-
-        chomp(@commit);
-
-    }
+    my $this_message = _format_message( $message, $self );
+    my @commit = $src->commit_tree( { -STDIN => $this_message }, $tree, map { ( '-p' => $_) } @parents );
 
     ### @commit
     $src->update_ref( 'refs/heads/' . $target_branch, $commit[0] );
@@ -167,18 +151,7 @@ sub _create_tree {
 
     ### @entries
 
-    my $sha = do {
-        use autodie 'system';
-        my $cmd = join '\n', @entries, q{};
-        $cmd  = qq{echo -en "$cmd" | git mktree};
-
-        #### $cmd
-        my $sha = `$cmd`;
-        chomp $sha;
-
-        ### tree created at: $sha
-        $sha;
-    };
+    my ($sha) = $repo->mktree({ -STDIN => join('\n', @entries, q{}) });
 
     return $sha;
 }
@@ -194,7 +167,7 @@ Dist::Zilla::Plugin::Git::CommitBuild - checkin build results on separate branch
 
 =head1 VERSION
 
-version 1.121770
+version 1.121800
 
 =head1 SYNOPSIS
 
